pype32.pype32.SectionHeader

Package pype32 :: Module pype32 :: Class SectionHeader |
[hide private]
[frames] | no frames]

# Class SectionHeader

source code

                     object --+
                              |
    baseclasses.BaseStructClass --+
                                  |
                                 SectionHeader

SectionHeader object.

Instance Methods | [hide private]
__init__(self, shouldPack=True) Class representation of the `IMAGE_SECTION_HEADER` structure. | source code
getType(self) Returns consts.IMAGE_SECTION_HEADER. | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__subclasshook__`
Inherited from baseclasses.BaseStructClass
__len__(self) | source code
__str__(self) str(x) | source code
dict |
getFields(self) Returns all the class attributues. | source code
sizeof(self) | source code

Static Methods | [hide private]
SectionHeader |
parse(readDataInstance) Returns a new SectionHeader object. | source code

Instance Variables | [hide private]
| name String name.
| misc DWORD misc.
| virtualAddress DWORD virtualAddress.
| sizeOfRawData DWORD sizeOfRawData.
| pointerToRawData DWORD pointerToRawData.
| pointerToRelocations DWORD pointerToRelocations.
| pointerToLineNumbers DWORD pointerToLineNumbers.
| numberOfRelocations WORD numberOfRelocations.
| numberOfLinesNumbers WORD numberOfLinesNumbers.
| characteristics DWORD characteristics.

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, shouldPack=True) (Constructor) | source code
Class representation of the `IMAGE_SECTION_HEADER` structure. Parameters: `shouldPack` (bool) - (Optional) If set to `True`, the object will be packed. If set to `False`, the object won't be packed. Overrides: object.__init__ See Also: http://msdn.microsoft.com/en-us/library/windows/desktop/ms680341%28v=vs.85%29.aspx

### parse(readDataInstance) Static Method | source code
Returns a new SectionHeader object. Parameters: `readDataInstance` (ReadData) - A ReadData object with data to be parsed as a SectionHeader object. Returns: SectionHeader A new SectionHeader object.

### getType(self) | source code
Returns consts.IMAGE_SECTION_HEADER. Raises: `NotImplementedError` - The method wasn't implemented in the inherited class. Overrides: baseclasses.BaseStructClass.getType